@@ -3,7 +3,7 @@ import importlib
 from fnmatch import fnmatch
 from functools import lru_cache
 from pathlib import Path
-from typing import Optional, Tuple
+from typing import FrozenSet, Iterable, Optional, Tuple
 
 from isort import sections
 from isort.settings import DEFAULT_CONFIG, Config
@@ -60,10 +60,31 @@ def _known_pattern(name: str, config: Config) -> Optional[Tuple[str, str]]:
     return None
 
 
-def _src_path(name: str, config: Config) -> Optional[Tuple[str, str]]:
-    for src_path in config.src_paths:
-        root_module_name = name.split(".")[0]
+def _src_path(
+    name: str,
+    config: Config,
+    src_paths: Optional[Iterable[Path]] = None,
+    prefix: Tuple[str, ...] = (),
+) -> Optional[Tuple[str, str]]:
+    if src_paths is None:
+        src_paths = config.src_paths
+
+    root_module_name, *nested_module = name.split(".", 1)
+    new_prefix = prefix + (root_module_name,)
+    namespace = ".".join(new_prefix)
+
+    for src_path in src_paths:
         module_path = (src_path / root_module_name).resolve()
+        if not prefix and not module_path.is_dir() and src_path.name == root_module_name:
+            module_path = src_path.resolve()
+        if nested_module and (
+            namespace in config.namespace_packages
+            or (
+                config.auto_identify_namespace_packages
+                and _is_namespace_package(module_path, config.supported_extensions)
+            )
+        ):
+            return _src_path(nested_module[0], config, (module_path,), new_prefix)
         if (
             _is_module(module_path)
             or _is_package(module_path)
@@ -89,6 +110,32 @@ def _is_package(path: Path) -> bool:
     return exists_case_sensitive(str(path)) and path.is_dir()
 
 
+def _is_namespace_package(path: Path, src_extensions: FrozenSet[str]) -> bool:
+    if not _is_package(path):
+        return False
+
+    init_file = path / "__init__.py"
+    if not init_file.exists():
+        filenames = [
+            filename for filename in path.iterdir() if filename.suffix.lstrip(".") in src_extensions
+        ]
+        if filenames:
+            return False
+    else:
+        with init_file.open() as open_init_file:
+            file_start = open_init_file.read(4096)
+            if (
+                "__import__('pkg_resources').declare_namespace(__name__)" not in file_start
+                and '__import__("pkg_resources").declare_namespace(__name__)' not in file_start
+                and "__path__ = __import__('pkgutil').extend_path(__path__, __name__)"
+                not in file_start
+                and '__path__ = __import__("pkgutil").extend_path(__path__, __name__)'
+                not in file_start
+            ):
+                return False
+    return True
+
+
 def _src_path_is_module(src_path: Path, module_name: str) -> bool:
     return (
         module_name == src_path.name and src_path.is_dir() and exists_case_sensitive(str(src_path))
